@@ -181,14 +181,24 @@ flickcurl_write_callback(void *ptr, size_t size, size_t nmemb,
 
 
 /**
- * flickcurl_new:
+ * flickcurl_new_with_handle:
+ * @curl_handle: CURL* handle
  *
- * Create a Flickcurl sesssion
+ * Create a Flickcurl sesssion from an existing CURL* handler
+ *
+ * This allows setting up or re-using an existing CURL handle with
+ * Flickcurl, however the library will call curl_easy_setopt to set
+ * options based on the operation being performed.  If these need to
+ * be over-ridden, use flickcurl_set_curl_setopt_handler() to adjust
+ * the options.
+ *
+ * NOTE: The type of @handle is void* so that curl headers are
+ * optional when compiling against flickcurl.
  *
  * Return value: new #flickcurl object or NULL on fialure
  */
 flickcurl*
-flickcurl_new(void)
+flickcurl_new_with_handle(void* curl_handle)
 {
   flickcurl* fc;
 
@@ -203,6 +213,7 @@ flickcurl_new(void)
   /* DEFAULT delay between requests is 1000ms i.e 1 request/second max */
   fc->request_delay = 1000;
   
+  fc->curl_handle = (CURL*)curl_handle;
   if(!fc->curl_handle) {
     fc->curl_handle = curl_easy_init();
     fc->curl_init_here = 1;
@@ -232,6 +243,19 @@ flickcurl_new(void)
 }
 
 
+/**
+ * flickcurl_new:
+ *
+ * Create a Flickcurl sesssion
+ *
+ * Return value: new #flickcurl object or NULL on fialure
+ */
+flickcurl*
+flickcurl_new(void)
+{
+  return flickcurl_new_with_handle(NULL);
+}
+
 /**
  * flickcurl_free:
  * @fc: flickcurl object
@@ -1351,7 +1375,9 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
     /* Set the form info */
     curl_easy_setopt(fc->curl_handle, CURLOPT_HTTPPOST, post);
   }
-  
+
+  if(fc->curl_setopt_handler)
+    fc->curl_setopt_handler(fc->curl_handle, fc->curl_setopt_handler_data);
 
 #ifdef FLICKCURL_DEBUG
   fprintf(stderr, "Resolving URI '%s' with method %s\n", 
@@ -1783,7 +1809,9 @@ static const char* flickcurl_field_value_type_label[VALUE_TYPE_LAST+1] = {
   "uri",
   "<internal>person ID",
   "<internal>media type",
-  "<internal>tag string"
+  "<internal>tag string",
+  "<internal>collection id",
+  "<internal>icon photos"
 };
 
 
@@ -2311,3 +2339,34 @@ flickcurl_search_params_init(flickcurl_search_params* params)
 
   return 0;
 }
+
+
+/**
+ * flickcurl_set_curl_setopt_handler:
+ * @fc: flickcurl object
+ * @curl_handler: curl set options handler (or NULL)
+ * @curl_handler_data: user data for handler (or NULL)
+ *
+ * Set curl set option callback handler.
+ *
+ * This handler is called for every curl request after all internal
+ * curl_easy_setopt calls are made on the internal CURL* handle and
+ * just before curl_easy_perform is invoked to start the retrieval.
+ * Thus, this callback can override any internal configuration.
+ *
+ * If a simple once-only CURL configuration is needed, using
+ * flickcurl_new_with_handle() may be easier.
+ *
+ * WARNING: The @curl_handler callback is called with 2 void args in
+ * the order user data (@curl_handler_data value), curl_handle (CURL*
+ * pointer) - take care to use them correct in implementation.
+ *
+ */
+void
+flickcurl_set_curl_setopt_handler(flickcurl *fc,
+                                  flickcurl_curl_setopt_handler curl_handler,
+                                  void* curl_handler_data)
+{
+  fc->curl_setopt_handler = curl_handler;
+  fc->curl_setopt_handler_data = curl_handler_data;
+}
