@@ -525,6 +525,33 @@ typedef struct {
 } flickcurl_location;
   
 
+/**
+ * flickcurl_note: 
+ * @id: note identifier (per-photo)
+ * @author: author (may be NULL)
+ * @authorname: author real name (may be NULL)
+ * @x: The left coordinate of the note
+ * @y: The top coordinate of the note
+ * @w: The width of the note
+ * @h: The height of the note
+ * @text: The description of the note
+ *
+ * A note attached to a rectangular area on a photo.
+ *
+ * A Photo Note.
+ */
+typedef struct flickcurl_note_s {
+  int id;
+  char* author;
+  char* authorname;
+  unsigned int x;
+  unsigned int y;
+  unsigned int w;
+  unsigned int h;
+  char* text;
+} flickcurl_note;
+
+
 /**
  * flickcurl_place_type:
  * @FLICKCURL_PLACE_LOCATION: a general location
@@ -742,6 +769,8 @@ typedef struct {
  * @place: place
  * @video: video (may be NULL)
  * @media_type: "photo" or "video"
+ * @notes: array of notes (may be NULL)
+ * @notes_count: size of notes array
  *
  * A photo or video.
  *
@@ -760,6 +789,9 @@ typedef struct flickcurl_photo_s {
   flickcurl_video* video;
 
   char *media_type;
+
+  flickcurl_note** notes;
+  int notes_count;
 } flickcurl_photo;
 
 
@@ -1148,6 +1180,9 @@ typedef struct {
  * @photos_count: number of photos in @photos array if @format is NULL. Undefined on failure
  * @content: raw content if @format is not NULL.  Also may be NULL on failure.
  * @content_length: size of @content if @format is not NULL. Undefined on failure
+ * @page: current photo list page
+ * @per_page: current photo list per-page
+ * @total_count: total number of photos available of which the current @page and @per_page is a slice
  *
  * Photos List result.
  */
@@ -1157,6 +1192,9 @@ typedef struct {
   int photos_count;
   char* content;
   size_t content_length;
+  int page;
+  int per_page;
+  int total_count;
 } flickcurl_photos_list;
 
 
@@ -2163,6 +2201,12 @@ FLICKCURL_API
 int flickcurl_photosets_orderSets(flickcurl* fc, const char** photoset_ids_array);
 FLICKCURL_API
 int flickcurl_photosets_removePhoto(flickcurl* fc, const char* photoset_id, const char* photo_id);
+FLICKCURL_API
+int flickcurl_photosets_removePhotos(flickcurl* fc, const char* photoset_id, const char** photo_ids_array);
+FLICKCURL_API
+int flickcurl_photosets_reorderPhotos(flickcurl* fc, const char* photoset_id, const char** photo_ids_array);
+FLICKCURL_API
+int flickcurl_photosets_setPrimaryPhoto(flickcurl* fc, const char* photoset_id, const char* photo_id);
 
 /* flickr.photosets.comments */
 FLICKCURL_API
@@ -2196,6 +2240,8 @@ flickcurl_method* flickcurl_reflection_getMethodInfo(flickcurl* fc, const char*
 
 /* flickr.stats */
 FLICKCURL_API
+int flickcurl_stats_getCSVFiles(flickcurl* fc);
+FLICKCURL_API
 flickcurl_stat** flickcurl_stats_getCollectionDomains(flickcurl* fc, const char* date, const char* collection_id, int per_page, int page);
 FLICKCURL_API
 flickcurl_stat** flickcurl_stats_getCollectionReferrers(flickcurl* fc, const char* date, const char* domain, const char* collection_id, int per_page, int page);
